@@ -197,6 +197,8 @@ class googleRoutesearchDownloader(Thread):
                 pass
 
 
+            str_no_street_name = re.sub(r'<[^>]*?>', ' ', str_no_street_name )
+            str_no_street_name = str_no_street_name.replace("  ", " ")
 
 
 
@@ -901,7 +903,7 @@ class google_routesearch:
 
     def on_changed_dis (self,picker,dialog):
         str = picker.get_value()
-        for i in range( 100, 1500, 100):
+        for i in range( 50, 1500, 50):
             if i == int(str):
                 self.CONFIG['google_routesearch_auto_recal'] = str
                 break
@@ -1017,7 +1019,7 @@ class google_routesearch:
         bt_a = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,"Add")
         bt_a.connect("clicked", self.on_add)
-        hbox.pack_start( bt_a, True)
+        hbox.pack_start( bt_a, False)
 
 
         bt_search = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
