@@ -109,7 +109,7 @@ class tangogps_friend:
         tr = []
         for p in self.friend:
             item_str = ("%s" % (p[3]))
-            print "item_str[",item_str,"] p[3][",p[3],"] str[",str,"]"
+            #print "item_str[",item_str,"] p[3][",p[3],"] str[",str,"]"
             if item_str.find(str) <> -1:
                 tr.append(p)
         return tr
