@@ -10,7 +10,7 @@ as published by the Free Software Foundation; version 2.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See theF
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
@@ -40,6 +40,7 @@ from h_deb import *
 from h_config_sl import *
 from h_UI_searchDialog import *
 from h_UI_mainMenuDialog import *
+from h_UI_detailsWindow import *
 from GpsManager import *
 from BuildPluginsList import *
 
@@ -346,9 +347,10 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                         mi.connect("activate",self.on_route_to_it,c[4],c[5])
                         m.append(mi)
 
-                    #mi = gtk.MenuItem("___________Details")
-                    #mi.connect("activate",self.on_details,c[4], c[5], c[6])
-                    #m.append(mi)
+                    if type(c[6]) <> str:
+                        mi = gtk.MenuItem("___________Details")
+                        mi.connect("activate",self.on_details,c[6])
+                        m.append(mi)
 
                     m.show_all()
                     m.popup( None, None, None , 2, 0)
@@ -357,17 +359,9 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
             print "YosmapaOSD press in:",( time.time()-t )
         return False
 
-    def on_details(self, w, lat, lon, str):
-        point = []
-        for p in self.osmMapa.markers:
-            if p[0] == lat and p[1] == lon and p[3] == str:
-                point = p
-                break
-        for p in self.osmMapa.show_find_results:
-            if p[0] == lat and p[1] == lon and p[3] == str:
-                point = p
-                break
-        print "found details point",point
+    def on_details(self, w, point):
+        w = DetailsWindow( self.osmMapa, point )
+
 
     def on_route_to_it(self, w, lat, lon):
         p = None
@@ -549,6 +543,7 @@ class UI(gtk.Window):
 4        image (pixbuf),
 5        osm_point (gobject) || None,
 6        zoom (int) start draw from zoom
+7        {} details
     )
     """
 
@@ -640,7 +635,7 @@ class UI(gtk.Window):
                 if zoom>10 and m[3]:
                     if icons_on_screen < 8:
                         icons_on_screen+=1
-                        self.draw_cloud_byll(cr, lt, ln, m[3])
+                        self.draw_cloud_byll(cr, m)
             else:
                 if m[5]:
                     self.osm.image_remove(m[5])
@@ -779,10 +774,18 @@ class UI(gtk.Window):
             dis = self.distance_to_string( self.distance( latc, lonc, lat, lon) )
             cr.show_text("%s"%dis)
 
-    def draw_cloud_byll(self, cr, lat, lon, str, font_size = 13, Fifek = True):
-        x,y = self.osm.geographic_to_screen(lat,lon)
+    def draw_cloud_byll(self, cr, lat, lon = "", str = "", font_size = 13, Fifek = True):
+        if lon == "" and str == "":
+            x,y = self.osm.geographic_to_screen(lat[0],lat[1])
+            str = lat
         self.draw_cloud(cr, x, y, str, font_size, Fifek)
     def draw_cloud(self, cr, x, y, str, font_size = 13, Fifek = True):
+
+        point = None
+        if type(str) <> str:
+            point = str
+            str = point[3]
+
         if str == "":
             return None
         if x<0:
@@ -851,8 +854,12 @@ class UI(gtk.Window):
             cr.move_to(x+2,y+line_height+1)
             cr.show_text(str)
 
-
-        self.clikable_clouds.append( [ x,y,x+width,y+height, float(math.degrees(rlat)), float(math.degrees(rlon)), str ] )
+        if Fifek:
+            if point:
+                point_data = point
+            else:
+                point_data = str
+            self.clikable_clouds.append( [ x,y,x+width,y+height, float(math.degrees(rlat)), float(math.degrees(rlon)), point_data ] )
 
         return True
 
